@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2016-09-27'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2016-12-25'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -132,7 +132,7 @@ bash versions 4.2-4.3):
 1) quotes and backslashes are stripped (bash's `COMP_WORDS` contains all the
    quotes and backslashes);
 
-2) quoted phrase that contain spaces, or phrase that contains escaped spaces is
+2) quoted phrase that contains spaces, or phrase that contains escaped spaces is
    parsed as a single word. For example:
 
     command "First argument" Second\ argument
@@ -551,7 +551,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.28 of Complete::Bash (from Perl distribution Complete-Bash), released on 2016-09-27.
+This document describes version 0.29 of Complete::Bash (from Perl distribution Complete-Bash), released on 2016-12-25.
 
 =head1 DESCRIPTION
 
@@ -608,7 +608,7 @@ as what you get from bash in C<COMP_LINE> environment variable) into words. This
 makes it easy for the other functions to generate completion answer. See the
 documentation for that function for more details.
 
-C<format_completion> is what you use to format completion answer structure for
+C<format_completion()> is what you use to format completion answer structure for
 bash.
 
 =head1 FUNCTIONS
@@ -738,7 +738,7 @@ bash versions 4.2-4.3):
 1) quotes and backslashes are stripped (bash's C<COMP_WORDS> contains all the
    quotes and backslashes);
 
-2) quoted phrase that contain spaces, or phrase that contains escaped spaces is
+2) quoted phrase that contains spaces, or phrase that contains escaped spaces is
    parsed as a single word. For example:
 
  command "First argument" Second\ argument
@@ -895,7 +895,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-B
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Bash>.
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Bash>.
 
 =head1 BUGS
 
@@ -907,7 +907,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<Complete>, the convention that this module uses.
+L<Complete>, the convention that this module follows.
 
 Some higher-level modules that use this module (so you don't have to use this
 module directly): L<Getopt::Long::Complete> (via L<Complete::Getopt::Long>),
